
# Slot: multivalued


true means that slot can have more than one value

URI: [linkml:multivalued](https://w3id.org/linkml/multivalued)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
